#
# Sysconfig.pm: system configuration for sbuild
# Copyright © 2007-2008 Roger Leigh <rleigh@debian.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see
# <http://www.gnu.org/licenses/>.
#
#######################################################################

package Sbuild::Sysconfig;

use strict;
use warnings;

BEGIN {
    use Exporter ();
    our (@ISA, @EXPORT_OK);

    @ISA = qw(Exporter);

    @EXPORT_OK = qw($version $release_date %paths %programs);
}

our $version = "0.59.0";
our $release_date = "02 Aug 2009";

# Paths
my $prefix = "/usr";
my $exec_prefix = "${prefix}";
# Depend on prefix
my $includedir = "${prefix}/include";
my $localstatedir = "/var";
my $sharedstatedir = "${prefix}/com";
my $sysconfdir = "/etc";
# Depend on exec_prefix
my $bindir = "${exec_prefix}/bin";
my $libdir = "${exec_prefix}/lib";
my $libexecdir = "/usr/share";
my $sbindir = "${exec_prefix}/sbin";
# Data directories
my $datarootdir = "${prefix}/share";
my $datadir = "${datarootdir}";
my $localedir = "${datarootdir}/locale";
my $mandir = "${prefix}/share/man";

our %paths = (
    'PREFIX' => $prefix,
    'EXEC_PREFIX' => $exec_prefix,
    'INCLUDEDIR' => $includedir,
    'LOCALSTATEDIR' => $localstatedir,
    'SHAREDSTATEDIR' => $sharedstatedir,
    'SYSCONFDIR' => $sysconfdir,
    'BINDIR' => $bindir,
    'LIBDIR' => $libdir,
    'LIBEXECDIR' => $libexecdir,
    'SBINDIR' => $sbindir,
    'DATAROOTDIR' => $datarootdir,
    'DATADIR' => $datadir,
    'LOCALEDIR' => $localedir,
    'MANDIR' => $mandir,
    'BUILDD_CONF' => "/etc/buildd/buildd.conf",
    'BUILDD_SYSCONF_DIR' => "/etc/buildd",
    'SBUILD_CONF' => "/etc/sbuild/sbuild.conf",
    'SBUILD_LIBEXEC_DIR' => "/usr/share/sbuild",
    'SBUILD_LOCALSTATE_DIR' => "$localstatedir/lib/sbuild",
    'SBUILD_SYSCONF_DIR' => "/etc/sbuild",
    'SCHROOT_CONF' => "/etc/schroot/schroot.conf",
    'SCHROOT_SYSCONF_DIR' => "/etc/schroot",
    'WANNA_BUILD_CONF' => "/etc/wanna_build/wanna-build.conf",
    'WANNA_BUILD_LOCALSTATE_DIR' => "$localstatedir/lib/wanna-build",
    'WANNA_BUILD_LIBEXEC_DIR' => "/usr/share/wanna-build"
);

# Programs:
our %programs = (
    'APT_CACHE' => '/usr/bin/apt-cache',
    'APT_GET' => '/usr/bin/apt-get',
    'CHMOD' => '/bin/chmod',
    'DATE' => '/bin/date',
    'DCMD' => '/usr/bin/dcmd',
    'DF' => '/bin/df',
    'DPKG' => '/usr/bin/dpkg',
    'DPKG_ARCHITECTURE' => '/usr/bin/dpkg-architecture',
    'DPKG_BUILDPACKAGE' => '/usr/bin/dpkg-buildpackage',
    'DPKG_PARSECHANGELOG' => '/usr/bin/dpkg-parsechangelog',
    'DPKG_SOURCE' => '/usr/bin/dpkg-source',
    'DU' => '/usr/bin/du',
    'FAKEROOT' => '/usr/bin/fakeroot',
    'GPG' => '',
    'HOSTNAME' => '/bin/hostname',
    'MAN' => '/usr/bin/man',
    'MD5SUM' => '/usr/bin/md5sum',
    'PGP' => '',
    'PS' => '',
    'RM' => '/bin/rm',
    'SCHROOT' => '/usr/bin/schroot',
    'SENDMAIL' => '/usr/sbin/sendmail',
    'SHELL' => '/bin/bash',
    'SSH' => '/usr/bin/ssh',
    'SU' => '/bin/su',
    'SUDO' => '/usr/bin/sudo',
    'TEMPFILE' => '/bin/tempfile'
);

1;
